@@ -13,13 +13,13 @@
 ##############################################################################
 """Address Book Views
 
-$Id: browser.py 76933 2007-06-22 02:20:21Z srichter $
+$Id: browser.py 81280 2007-10-31 16:50:06Z srichter $
 """
 __docformat__ = "reStructuredText"
 import zope.component
 import zope.location
 from zope.app.container import btree
-from zope.app.session.interfaces import ISession
+from zope.session.interfaces import ISession
 from zope.pagetemplate.interfaces import IPageTemplate
 from zope.publisher import browser
 from zope.traversing.browser import absoluteURL
@@ -51,7 +51,7 @@ class AddressForm(subform.EditSubForm, form.EditForm):
     def updateWidgets(self):
         super(AddressForm, self).updateWidgets()
         for name, widget in self.widgets.items():
-            widget.css += ' ' + name
+            widget.addClass(name)
 
     @property
     def title(self):
@@ -107,9 +107,9 @@ class AddressesForm(form.AddForm):
         self.addressForms = []
         for name, address in self.getContent().items():
             form = AddressForm(address, self.request, self.parentForm)
-            form.name = name
+            form.name = str(name)
             # The prefix is created at runtime to guarantee uniqueness
-            form.prefix = self.prefix + name + '.'
+            form.prefix = self.prefix + str(name) + '.'
             form.update()
             # Updating the address can also mean its deletion. If deleted, it
             # is not added to the list.
@@ -133,7 +133,7 @@ class PhoneForm(subform.EditSubForm):
     def updateWidgets(self):
         super(PhoneForm, self).updateWidgets()
         for name, widget in self.widgets.items():
-            widget.css += ' ' + name
+            widget.addClass(name)
 
     def getContent(self):
         # Get the phone attribute from the contact
@@ -194,7 +194,7 @@ class EMailForm(subform.EditSubForm, form.EditForm):
     def updateWidgets(self):
         super(EMailForm, self).updateWidgets()
         for name, widget in self.widgets.items():
-            widget.css += ' email'
+            widget.addClass(u'email')
 
     @button.handler(form.AddForm.buttons['add'])
     def handleAdd(self, action):
@@ -214,7 +214,7 @@ class EMailsForm(form.AddForm):
     def updateWidgets(self):
         super(EMailsForm, self).updateWidgets()
         for name, widget in self.widgets.items():
-            widget.css += ' email'
+            widget.addClass(u'email')
 
     def create(self, data):
         address = contact.EMail(**data)
