@@ -13,11 +13,11 @@
 ##############################################################################
 """Spreadsheet Implementation
 
-$Id: spreadsheet.py 76933 2007-06-22 02:20:21Z srichter $
+$Id: spreadsheet.py 81280 2007-10-31 16:50:06Z srichter $
 """
 __docformat__ = "reStructuredText"
 import zope.interface
-from zope.app.session.interfaces import ISession
+from zope.session.interfaces import ISession
 from z3c.form import button, field, form, interfaces
 from z3c.formui import layout
 from zc.table import table, column
@@ -88,7 +88,7 @@ class EditRow(form.EditForm):
         super(EditRow, self).__init__(spreadsheet.context, spreadsheet.request)
         self.fields = spreadsheet.rowFields
         self.content = content
-        self.prefix = content.__name__+'.'
+        self.prefix = str(content.__name__) + '.'
         self.sessionKey = spreadsheet.sessionKey
 
     @property
