@@ -13,15 +13,16 @@
 ##############################################################################
 """Generic Wizard Implementation
 
-$Id: wizard.py 75942 2007-05-24 14:53:46Z srichter $
+$Id: wizard.py 81280 2007-10-31 16:50:06Z srichter $
 """
 __docformat__ = "reStructuredText"
+import zope.component
 import zope.interface
-from zope.app.session.interfaces import ISession
+from zope.session.interfaces import ISession
 from zope.viewlet.viewlet import CSSViewlet
 
 from z3c.form import button, field, form, subform
-from z3c.form.interfaces import IWidgets
+from z3c.form.interfaces import IWidgets, IDataManager
 from z3c.formui import layout
 from z3c.formdemo.wizard import interfaces
 
@@ -48,7 +49,7 @@ class IWizardButtons(zope.interface.Interface):
 
     finish = button.Button(
         title=u'Finish',
-        condition=lambda form: form.isLastStep())
+        condition=lambda form: form.isLastStep() and form.isComplete())
     zope.interface.alsoProvides(
         finish, (interfaces.ISaveButton, interfaces.IForwardButton))
 
@@ -58,6 +59,22 @@ class Step(subform.EditSubForm):
     name = None
     label = None
 
+    def isComplete(self):
+        """See interfaces.IStep
+
+        This implementation checks that all required fields have been filled
+        out.
+        """
+        content = self.getContent()
+        for field in self.fields.values():
+            if not field.field.required:
+                continue
+            dm = zope.component.getMultiAdapter(
+                (content, field.field), IDataManager)
+            if dm.get() is field.field.missing_value:
+                return False
+        return True
+
     @button.handler(interfaces.ISaveButton)
     def handleAllButtons(self, action):
         self.handleApply(self, action)
@@ -77,6 +94,7 @@ class WizardButtonActions(button.ButtonActions):
 
 
 class Wizard(layout.FormLayoutSupport, form.Form):
+    zope.interface.implements(interfaces.IWizard)
 
     sessionKey = 'z3c.formdemo.wizard'
     buttons = button.Buttons(IWizardButtons)
@@ -85,7 +103,15 @@ class Wizard(layout.FormLayoutSupport, form.Form):
     steps = None
     step = None
 
+    def isComplete(self):
+        for name, StepClass in self.steps:
+            step = StepClass(self.getContent(), self.request, self)
+            if not step.isComplete():
+                return False
+        return True
+
     def getCurrentStep(self):
+        """See interfaces.IWizard"""
         session = ISession(self.request)[self.sessionKey]
         if 'step' in self.request:
             name = self.request['step']
@@ -99,9 +125,11 @@ class Wizard(layout.FormLayoutSupport, form.Form):
         return inst
 
     def isFirstStep(self):
+        """See interfaces.IWizard"""
         return isinstance(self.step, self.steps[0][1])
 
     def isLastStep(self):
+        """See interfaces.IWizard"""
         return isinstance(self.step, self.steps[-1][1])
 
     @property
@@ -151,6 +179,13 @@ class Wizard(layout.FormLayoutSupport, form.Form):
         self.request.response.redirect(url)
 
 
+    @button.handler(IWizardButtons['save'])
+    def handleSave(self, action):
+        # Saving can change the conditions for the finish button, so we need
+        # to reconstruct the button actions, since we do not redirect.
+        self.updateActions()
+
+
     @button.handler(IWizardButtons['finish'])
     def handleFinish(self, action):
         session = ISession(self.request)[self.sessionKey]
